@@ -4,7 +4,7 @@
 #'
 #' @description This function is a public function and will fetch get 24 hr stats for the provided currency pair (product_id). Volume is in base currency units. open, high, low are in quote currency units.
 #'
-#' @param product_id Optional character parameter. This is a case insensitive value of the product id for which the order book is desired. Default to \code{'LTC-USD'}. For all valid product ids, refer to \code{\link{public_info}}.
+#' @param product_id Optional character parameter. This is a case insensitive value of the product id for which the order book is desired. Default to \code{'BTC-USD'}. For all valid product ids, refer to \code{\link{public_info}}.
 #'
 #' @return  Dataframe with a single row of product's last 24 hour stats.
 #'
@@ -15,8 +15,8 @@
 #'
 #' @export
 
-
-public_daystats <- function(product_id = "LTC-USD") {
+# output tested on WIN. Macos pending
+public_daystats <- function(product_id = "BTC-USD") {
   #case remediation----
   product_id <- toupper(product_id)
 
@@ -24,11 +24,10 @@ public_daystats <- function(product_id = "LTC-USD") {
   req.url <- paste0("/products/", product_id, "/stats")
 
   #fetch response----
-  content <- parse_response(path = req.url)
+  response <- parse_response(path = req.url)
 
   #transform----
-  content <- lapply(content, as.numeric)
-  content <- as.data.frame(content)
+  content <- as.data.frame(fromJSON(rawToChar(response$content)))
 
   #return----
   return(content)
